﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace C1DCreaterUtil
{
    public partial class Form1 : Form
    {
        #region **Variables
        string path;
        C1.C1Preview.C1DocumentFormatEnum select;
        #endregion

        #region **Form Constructor
        public Form1()
        {
            InitializeComponent();
            //Default file save path 
            path = Application.StartupPath.Substring(0, Application.StartupPath.IndexOf(@"\bin"));
            path += @"\C1Docs\";

        }

        #endregion

        #region **Events
        //Set the C1PrintDocument FileFormat
        private void radioButton1_CheckedChanged(object sender, EventArgs e)
        {
            RadioButton rdn = sender as RadioButton;
            select = (C1.C1Preview.C1DocumentFormatEnum)Enum.Parse(typeof(C1.C1Preview.C1DocumentFormatEnum), rdn.Text);
        }

        //Select the file to be saved 
        private void btnSelect_Click(object sender, EventArgs e)
        {
            OpenFileDialog odialog = new OpenFileDialog();
            odialog.Title = "Select File to be converted to C1PrintDocument";
            odialog.Multiselect = false;
            odialog.Filter = "VSView documents (*.vp)|*.vp|RTF documents (*.rtf)|*.rtf|Text documents (*.txt)|*.txt";


            if (odialog.ShowDialog() == DialogResult.OK)
            {
                switch (odialog.FilterIndex)
                {
                    case 1: createVPC1D(odialog.FileName);
                        break;
                    case 2: createRtfC1D(odialog.FileName);
                        break;
                    case 3: createTxtC1D(odialog.FileName);
                        break;
                }
            }
        }
        #endregion

        #region **Methods
        private void createVPC1D(string fileName)
        {
            try
            {
                c1PrintDocument1.Body.Children.Clear();
                _vp.LoadDoc(fileName, false);
                for (short page = 1; page <= _vp.PageCount; ++page)
                {
                    _vp.PreviewPage = page;
                    c1PrintDocument1.PageLayout.PageSettings.TopMargin = 0;
                    c1PrintDocument1.PageLayout.PageSettings.LeftMargin = 0;
                    if (_vp.Picture.Height < _vp.Picture.Width)
                        c1PrintDocument1.PageLayout.PageSettings.Landscape = true;
                    else
                        c1PrintDocument1.PageLayout.PageSettings.Landscape = false;
                    c1PrintDocument1.Body.Children.Add(new C1.C1Preview.RenderImage(_vp.Picture));
                }
                string savename = path + "VP_PrintDoc_" + DateTime.Now.ToString("yyyyMMddHHmmss") + "." + select; 
                c1PrintDocument1.Save(savename);
                MessageBox.Show("C1PrintDocument Saved! (" + savename + ")");
            }
            catch
            {
                MessageBox.Show(string.Format("Error loading {0}", fileName));
            }
        }

        private void createRtfC1D(string fileName)
        {
            try
            {
                c1PrintDocument1.Body.Children.Clear();
                System.IO.StreamReader sr = new System.IO.StreamReader(fileName);
                C1.C1Preview.RenderRichText rendertext = new C1.C1Preview.RenderRichText();
                rendertext.Rtf = sr.ReadToEnd();
                c1PrintDocument1.Body.Children.Add(rendertext);
                c1PrintDocument1.Generate();
                string savename = path + "RTF_PrintDoc_" + DateTime.Now.ToString("yyyyMMddHHmmss") + "." + select;
                c1PrintDocument1.Save(savename);
                MessageBox.Show("C1PrintDocument Saved! (" + savename + ")");
            }
            catch
            {
                MessageBox.Show(string.Format("Error loading {0}", fileName));
            }
        }

        private void createTxtC1D(string fileName)
        {
            try 
            {
                c1PrintDocument1.Body.Children.Clear();
                System.IO.StreamReader sr = new System.IO.StreamReader(fileName);
                C1.C1Preview.RenderText rendertext = new C1.C1Preview.RenderText();
                rendertext.Text = sr.ReadToEnd();
                c1PrintDocument1.Body.Children.Add(rendertext);
                c1PrintDocument1.Generate();
                string savename = path + "TXT_PrintDoc_" + DateTime.Now.ToString("yyyyMMddHHmmss") + "." + select;
                c1PrintDocument1.Save(savename);
                MessageBox.Show("C1PrintDocument Saved! (" + savename + ")");
            }
            catch
            {
            }
        }
        #endregion

      
    }
}
